==> websvn-2.3.3-7-any.pkg.tar.xz: srv/http/websvn/languages/slovenian.php <==
<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// slovenian.php
// Goran Kavrecic <goran.kavrecic@indea.si>
//
// Slovenian language strings (UTF-8 encoding)

$lang["LANGUAGETAG"] = "sl"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Slovenian";
$lang["LANGUAGENAMENATIVE"] = "Slovenščina";
$lang["LANGUAGENAMEHTML"] = "Sloven&#353;&#269;ina";

$lang["LOG"] = "Dnevnik";
$lang["DIFF"] = "Razlike";

$lang["NOREP"] = "Skladišče ni določeno";
$lang["NOPATH"] = "Ne najdem poti";
$lang["NOACCESS"] = "Nimate dovolj pravic za branje tega direktorija";
$lang["RESTRICTED"] = "Dostop zavrnjen";
$lang["SUPPLYREP"] = "Prosim nastavi pot do skladišča v include/config.php z \$config->parentPath ali \$config->addRepository<p>Poglej navodila za detajle";

$lang["DIFFREVS"] = "Razlike med različicama";
$lang["AND"] = "in";
$lang["REV"] = "Različica";
$lang["LINE"] = "Vrstica";
$lang["LINENO"] = "Vrstica št.";
$lang["SHOWENTIREFILE"] = "Prikaži celo datoteko";
$lang["SHOWCOMPACT"] = "Prikaži samo področja z razlikami";
$lang["IGNOREWHITESPACE"] = "Ignoriraj 'whitespace'";
$lang["REGARDWHITESPACE"] = "Upoštevaj 'whitespace'";

$lang["LISTING"] = "Drevesna struktura";
$lang["FILEDETAIL"] = "Podrobnosti";
$lang["VIEWAS"] = "Poglej kot";
$lang["DIFFPREV"] = "Primerjaj s prejšno";
$lang["BLAME"] = "Krivda";
$lang["BLAMEFOR"] = "Informacije o krivdi za različico";

$lang["REVINFO"] = "Informacija o različici";
$lang["GOYOUNGEST"] = "Skoči na zadnjo različico";
$lang["LASTMOD"] = "Zadnje spremembe";
$lang["LOGMSG"] = "Opombe";
$lang["CHANGES"] = "Spremembe";
$lang["SHOWCHANGED"] = "Prikaži spremenjene datoteke";
$lang["HIDECHANGED"] = "Skrij spremenjene datoteke";
$lang["NEWFILES"] = "Nove datoteke";
$lang["CHANGEDFILES"] = "Spremenjene datoteke";
$lang["DELETEDFILES"] = "Pobrisane datoteke";
$lang["VIEWLOG"] = "Poglej dnevnik";
$lang["PATH"] = "Pot";
$lang["AUTHOR"] = "Avtor";
$lang["AGE"] = "Starost";
$lang["CURDIR"] = "Trenutni direktorij";
$lang["TARBALL"] = "Tarball";
$lang["DOWNLOAD"] = "Naloži";

$lang["PREV"] = "Nazaj";
$lang["NEXT"] = "Naprej";
$lang["SHOWALL"] = "Prikaži vse";

$lang["BADCMD"] = "Napaka pri izvajanju tega ukaza";
$lang["UNKNOWNREVISION"] = "Ne najdem različice";

// $lang["POWERED"] = "Powered by <a href=\"http://www.websvn.info/\">WebSVN</a>";
$lang["PROJECTS"] = "Subversion projekti";
$lang["SERVER"] = "Subversion strežnik";

$lang["FILTER"] = "Možnosti filtriranja";
$lang["STARTLOG"] = "Od različice";
$lang["ENDLOG"] = "Do različice";
$lang["MAXLOG"] = "Max različic";
$lang["SEARCHLOG"] = "Išči po opombah";
$lang["CLEARLOG"] = "Pobriši trenutno iskanje";
$lang["MORERESULTS"] = "Poišči še...";
$lang["NORESULTS"] = "Med zapisi ni opomb z iskalnim nizem";
$lang["NOMORERESULTS"] = "Med zapisi ni več opomb z iskalnim nizem";
$lang["NOPREVREV"] = "Ni predhodne revizije";

$lang["RSSFEEDTITLE"] = "WebSVN RSS vir";
$lang["FILESMODIFIED"] = "datotek spremenjenih";
$lang["RSSFEED"] = "RSS vir";

$lang["DAYLETTER"] = "d";
$lang["HOURLETTER"] = "h";
$lang["MINUTELETTER"] = "m";
$lang["SECONDLETTER"] = "s";

$lang["GO"] = "Izvedi";

$lang["PATHCOMPARISON"] = "Primerjava poti";
$lang["COMPAREPATHS"] = "Primerjaj poti";
$lang["COMPAREREVS"] = "Primerjaj različici";
$lang["PROPCHANGES"] = "Spremembe lastnosti:";
$lang["CONVFROM"] = "Ta primerjava prikazuje spremembe potrebne za pretvorbo poti ";
$lang["TO"] = "V";
$lang["REVCOMP"] = "Reverzna primerjava";
$lang["COMPPATH"] = "Primerjaj pot:";
$lang["WITHPATH"] = "S potjo:";
$lang["FILEDELETED"] = "Datoteka pobrisana";
$lang["FILEADDED"] = "Nova datoteka";

==> websvn-2.6.1-1-any.pkg.tar.xz: srv/http/websvn/languages/slovenian.php <==
<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// slovenian.php
// Goran Kavrecic <goran.kavrecic@indea.si>
//
// Slovenian language strings (UTF-8 encoding)

$lang["LANGUAGETAG"] = "sl"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Slovenian";
$lang["LANGUAGENAMENATIVE"] = "Slovenščina";
$lang["LANGUAGENAMEHTML"] = "Sloven&#353;&#269;ina";

$lang["LOG"] = "Dnevnik";
$lang["DIFF"] = "Razlike";

$lang["NOREP"] = "Skladišče ni določeno";
$lang["NOPATH"] = "Ne najdem poti";
$lang["NOACCESS"] = "Nimate dovolj pravic za branje tega direktorija";
$lang["RESTRICTED"] = "Dostop zavrnjen";
$lang["SUPPLYREP"] = "Prosim nastavi pot do skladišča v include/config.php z \$config->parentPath ali \$config->addRepository<p>Poglej navodila za detajle";

$lang["DIFFREVS"] = "Razlike med različicama";
$lang["AND"] = "in";
$lang["REV"] = "Različica";
$lang["LINE"] = "Vrstica";
$lang["LINENO"] = "Vrstica št.";
$lang["SHOWENTIREFILE"] = "Prikaži celo datoteko";
$lang["SHOWCOMPACT"] = "Prikaži samo področja z razlikami";
$lang["IGNOREWHITESPACE"] = "Ignoriraj 'whitespace'";
$lang["REGARDWHITESPACE"] = "Upoštevaj 'whitespace'";

$lang["LISTING"] = "Drevesna struktura";
$lang["FILEDETAIL"] = "Podrobnosti";
$lang["VIEWAS"] = "Poglej kot";
$lang["DIFFPREV"] = "Primerjaj s prejšno";
$lang["BLAME"] = "Krivda";
$lang["BLAMEFOR"] = "Informacije o krivdi za različico";

$lang["REVINFO"] = "Informacija o različici";
$lang["GOYOUNGEST"] = "Skoči na zadnjo različico";
$lang["LASTMOD"] = "Zadnje spremembe";
$lang["LOGMSG"] = "Opombe";
$lang["CHANGES"] = "Spremembe";
$lang["SHOWCHANGED"] = "Prikaži spremenjene datoteke";
$lang["HIDECHANGED"] = "Skrij spremenjene datoteke";
$lang["NEWFILES"] = "Nove datoteke";
$lang["CHANGEDFILES"] = "Spremenjene datoteke";
$lang["DELETEDFILES"] = "Pobrisane datoteke";
$lang["VIEWLOG"] = "Poglej dnevnik";
$lang["PATH"] = "Pot";
$lang["AUTHOR"] = "Avtor";
$lang["AGE"] = "Starost";
$lang["CURDIR"] = "Trenutni direktorij";
$lang["TARBALL"] = "Tarball";
$lang["DOWNLOAD"] = "Naloži";

$lang["PREV"] = "Nazaj";
$lang["NEXT"] = "Naprej";
$lang["SHOWALL"] = "Prikaži vse";

$lang["BADCMD"] = "Napaka pri izvajanju tega ukaza";
$lang["UNKNOWNREVISION"] = "Ne najdem različice";

// $lang["POWERED"] = "Powered by <a href=\"https://websvnphp.github.io/\">WebSVN</a>";
$lang["PROJECTS"] = "Subversion projekti";
$lang["SERVER"] = "Subversion strežnik";

$lang["FILTER"] = "Možnosti filtriranja";
$lang["STARTLOG"] = "Od različice";
$lang["ENDLOG"] = "Do različice";
$lang["MAXLOG"] = "Max različic";
$lang["SEARCHLOG"] = "Išči po opombah";
$lang["CLEARLOG"] = "Pobriši trenutno iskanje";
$lang["MORERESULTS"] = "Poišči še...";
$lang["NORESULTS"] = "Med zapisi ni opomb z iskalnim nizem";
$lang["NOMORERESULTS"] = "Med zapisi ni več opomb z iskalnim nizem";
$lang["NOPREVREV"] = "Ni predhodne revizije";

$lang["RSSFEEDTITLE"] = "WebSVN RSS vir";
$lang["FILESMODIFIED"] = "datotek spremenjenih";
$lang["RSSFEED"] = "RSS vir";

$lang["DAYLETTER"] = "d";
$lang["HOURLETTER"] = "h";
$lang["MINUTELETTER"] = "m";
$lang["SECONDLETTER"] = "s";

$lang["GO"] = "Izvedi";

$lang["PATHCOMPARISON"] = "Primerjava poti";
$lang["COMPAREPATHS"] = "Primerjaj poti";
$lang["COMPAREREVS"] = "Primerjaj različici";
$lang["PROPCHANGES"] = "Spremembe lastnosti:";
$lang["CONVFROM"] = "Ta primerjava prikazuje spremembe potrebne za pretvorbo poti ";
$lang["TO"] = "V";
$lang["REVCOMP"] = "Reverzna primerjava";
$lang["COMPPATH"] = "Primerjaj pot:";
$lang["WITHPATH"] = "S potjo:";
$lang["FILEDELETED"] = "Datoteka pobrisana";
$lang["FILEADDED"] = "Nova datoteka";

$lang['SEARCH'] = "Iskanje";
$lang['SEARCH_PLACEHOLDER'] = "Poiščite predmete tukaj";
$lang['NOITEMSFOUND'] = "Ni najdenih predmetov";
